## 1.2.0.20250322 (2025-03-22)

Add `__all__` to `click-default-group` (#13694)

## 1.2.0.20241221 (2024-12-21)

Update to mypy 1.14 (#13272)

## 1.2.0.0 (2023-07-22)

Add stubs for click-default-group (#9304)

Co-authored-by: AlexWaygood <alex.waygood@gmail.com>
Co-authored-by: Avasam <samuel.06@hotmail.com>

